@@ -1,19 +1,19 @@
-##############################################
+##################################################
 #
 # semantyk 
-# Package | Semantyk Package.
+# Package | Semantyk
 #
 # Author: Daniel Bakas Amuchastegui
 # August 31, 2017
 # 
 # Copyright © Semantyk 2020. All rights reserved.
-#############################################
+##################################################
 
 from . import archive
 from . import av_reality
 from . import das
-from . import data_visualization_models
 from . import dots
+from . import dvm
 from . import games
 from . import learn
 from . import namespace
@@ -24,12 +24,16 @@ from . import uuid_generator
 
 from .archive import *
 from .av_reality import *
-from .data_visualization_models import *
 from .dots import *
+from .dvm import *
 from .games import *
 from .learn import *
 from .namespace import *
 from .sam import *
 from .store import *
 from .tools import *
-from .uuid_generator import *
\ No newline at end of file
+from .uuid_generator import *
+
+__author__ = """Daniel Bakas Amuchastegui"""
+__email__ = 'danielbakas@gmail.com'
+__version__ = '0.0.0.40'
\ No newline at end of file
