@@ -1,16 +1,18 @@
-##############################################
+##################################################
 #
 # core
-# Package | Core Package.
+# Package | Core
 #
 # Author: Daniel Bakas Amuchastegui
 # March 16, 2020
 # 
 # Copyright © Semantyk 2020. All rights reserved.
-#############################################
+##################################################
 
 from . import graph
 from . import model
+from . import resource
 
 from .graph import *
-from .model import *
\ No newline at end of file
+from .model import *
+from .resource import *
\ No newline at end of file
