@@ -1,13 +1,13 @@
-##############################################
+##################################################
 #
 # resource 
-# Module | Resource Module.
+# Module | Resource
 #
 # Author: Daniel Bakas Amuchastegui
 # March 18, 2020
 # 
-# Copyright © Semantyk 2020. All rights reserved.
-#############################################
+# Copyright © Semantyk 2020. All rights reserved. 
+##################################################
 
 from semantyk.namespace.namespace import RDF, RDFS, SMTK
 from semantyk.uuid_generator import generate_uuid 
@@ -108,7 +108,7 @@ class Resource(object):
         return hash(self.uri)
 
     def __str__(self):
-        result = self.id + 'Test'
+        result = self.id
         if self.dictionary:
             result += ':'
             for p in self.dictionary:
